@@ -1,5 +1,5 @@
 #  GNU Mailutils -- a suite of utilities for electronic mail
-#  Copyright (C) 2009-2012, 2014-2017 Free Software Foundation, Inc.
+#  Copyright (C) 2009-2020 Free Software Foundation, Inc.
 #
 #  GNU Mailutils is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -20,26 +20,27 @@ from mailutils.error import *
 
 def parse (str):
     try:
-	u = url.Url (str)
-        print "URL: %s" % u
+        u = url.Url (str)
+        print("URL: %s" % u)
 
-	print "\tscheme <%s>" % u.get_scheme ()
-	print "\tuser <%s>" %   u.get_user ()
+        print("\tscheme <%s>" % u.get_scheme ())
+        print("\tuser <%s>" %   u.get_user ())
 
         sec = u.get_secret ()
-	print "\tpasswd <%s>" % sec.password ()
-	sec.password_unref ()
+        if sec:
+            print("\tpasswd <%s>" % sec.password ())
+            sec.password_unref ()
 
- 	print "\tauth <%s>" %   u.get_auth ()
- 	print "\thost <%s>" %   u.get_host ()
- 	print "\tport %d" %     u.get_port ()
- 	print "\tpath <%s>" %   u.get_path ()
+        print("\tauth <%s>" %   u.get_auth ())
+        print("\thost <%s>" %   u.get_host ())
+        print("\tport %d" %     u.get_port ())
+        print("\tpath <%s>" %   u.get_path ())
 
         for i, param in enumerate (u.get_query ()):
-            print "\tquery[%d] %s" % (i, param)
+            print("\tquery[%d] %s" % (i, param))
 
-    except UrlError, e:
-        print e
+    except UrlError as e:
+        print(e)
 
 def parseinput ():
     try:
