@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2005-2008, 2010-2012, 2014-2015 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -242,7 +241,7 @@ mu_locker_set_default_expire_timeout (time_t t)
 }
 
 int
-mu_locker_set_default_external_program (char *path)
+mu_locker_set_default_external_program (char const *path)
 {
   char *p = strdup (path);
   if (!p)
