@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012, 2014-2016 Free Software Foundation, Inc.
+   Copyright (C) 2011-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,7 @@ _print_list_entry (void *item, void *data)
 	     (resp->type & MU_FOLDER_ATTRIBUTE_DIRECTORY) ? 'd' : '-',
 	     (resp->type & MU_FOLDER_ATTRIBUTE_FILE) ? 'f' : '-',
 	     resp->separator ? resp->separator : ' ',
-	     resp->level,
+	     resp->depth,
 	     resp->name);
   return 0;
 }
@@ -202,6 +202,7 @@ main (int argc, char **argv)
       mu_diag_funcall (MU_DIAG_ERROR, "mu_folder_create", fname, rc);
       return 1;
     }
+  mu_folder_attach_ticket (folder);
   
   rc = mu_folder_open (folder, MU_STREAM_READ);
   if (rc)
