@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2020 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ append_to_mailbox (mu_url_t url, msgset_t *msglist, int mark,
 
   for (mp = msglist; mp; mp = mp->next)
     {
-      status = util_get_message (mbox, mp->msg_part[0], &msg);
+      status = util_get_message (mbox, msgset_msgno (mp), &msg);
       if (status)
 	break;
 
@@ -95,10 +95,9 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
   int status;
   msgset_t *mp;
   mu_stream_t ostr, mstr;
-  mu_off_t size;
-  size_t lines;
   mu_message_t msg;
   mu_locker_t locker;
+  mu_stream_stat_buffer stat;
 
   status = mu_file_stream_create (&ostr, filename,
 				  MU_STREAM_CREAT|MU_STREAM_APPEND);
@@ -130,13 +129,18 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
       return 1;
     }
 
+  mu_stream_set_stat (ostr,
+		      MU_STREAM_STAT_MASK (MU_STREAM_STAT_OUT) |
+		      MU_STREAM_STAT_MASK (MU_STREAM_STAT_OUTLN),
+		      stat);
+  
   for (mp = msglist; mp; mp = mp->next)
     {
       mu_envelope_t env;
       const char *s, *d;
       int n;
-
-      status = util_get_message (mbox, mp->msg_part[0], &msg);
+      
+      status = util_get_message (mbox, msgset_msgno (mp), &msg);
       if (status)
 	break;
 
@@ -168,9 +172,6 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
 	  break;
 	}
 
-      totals->lines++;
-      totals->size += n;
-
       status = mu_message_get_streamref (msg, &mstr);
       if (status)
 	{
@@ -178,7 +179,7 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
 	  break;
 	}
 
-      status = mu_stream_copy (ostr, mstr, 0, &size);
+      status = mu_stream_copy_nl (ostr, mstr, 0, NULL);
       if (status)
 	{
 	  mu_error (_("Cannot append message: %s"), mu_strerror (status));
@@ -187,12 +188,6 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
 
       mu_stream_unref (mstr);
 
-      mu_stream_write (ostr, "\n", 1, NULL);
-
-      totals->size += size + 1;
-      mu_message_lines (msg, &lines);
-      totals->lines += lines + 1;
-
       if (mark)
 	{
 	  mu_attribute_t attr;
@@ -207,6 +202,9 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
   mu_locker_unlock (locker);
   mu_locker_destroy (&locker);
 
+  totals->size = stat[MU_STREAM_STAT_OUT];
+  totals->lines = stat[MU_STREAM_STAT_OUTLN];
+
   return 0;
 }
 
@@ -228,7 +226,7 @@ mail_copy0 (int argc, char **argv, int mark)
     {
       if (msgset_parse (argc, argv, MSG_NODELETED, &msglist))
 	return 1;
-      filename = util_outfolder_name (util_get_sender (msglist->msg_part[0], 1));
+      filename = util_outfolder_name (util_get_sender (msgset_msgno (msglist), 1));
     }
   else
     {
