@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
+   Copyright (C) 2009-2020 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,8 @@
  */
 
 int
-print_envelope (msgset_t *mspec, mu_message_t msg, void *data)
+print_stream_envelope (mu_stream_t str, msgset_t *mspec, mu_message_t msg,
+		       char const *pfx)
 {
   int status;
   mu_envelope_t env = NULL;
@@ -31,19 +32,25 @@ print_envelope (msgset_t *mspec, mu_message_t msg, void *data)
   if (status)
     {
       mu_error (_("%lu: Cannot get envelope"),
-		(unsigned long) mspec->msg_part[0]);
+		(unsigned long) msgset_msgno (mspec));
     }
   else
     {
       mu_envelope_sget_sender (env, &sender);
       mu_envelope_sget_date (env, &date);
-      if (data)
-	mu_printf ("%s ", (char*) data);
-      mu_printf ("%s %s", sender, date);
+      if (pfx)
+	mu_stream_printf (str, "%s ", pfx);
+      mu_stream_printf (str, "%s %s\n", sender, date);
     }
   return 0;
 }
 
+static int
+print_envelope (msgset_t *mspec, mu_message_t msg, void *data)
+{
+  return print_stream_envelope (mu_strout, mspec, msg, data);
+}
+
 int
 mail_envelope (int argc, char **argv)
 {
