@@ -30,7 +30,7 @@ hold0 (msgset_t *mspec, mu_message_t msg, void *data)
   mu_attribute_unset_userflag (attr, MAIL_ATTRIBUTE_MBOXED);
   mu_attribute_set_userflag (attr, MAIL_ATTRIBUTE_PRESERVED);
 
-  set_cursor (mspec->msg_part[0]);
+  set_cursor (msgset_msgno (mspec));
   
   return 0;
 }
