@@ -16,20 +16,16 @@
 
 #include "mail.h"
 
-#define PART_WIDTH 8
-
 static int
 show_part (struct mime_descend_closure *closure, void *data)
 {
-  size_t width;
-  size_t size = 0;
+  char *msp;
+  size_t size;
+  
+  msp = msgset_str (closure->msgset);
+  mu_printf ("%-16s %-25s", msp, closure->type);
+  free (msp);
   
-  format_msgset (mu_strout, closure->msgset, &width);
-  for (; width < 5; width++)
-    mu_stream_write (mu_strout, " ", 1, NULL);
-    
-  mu_printf (" %-25s", closure->type);
-
   mu_message_size (closure->message, &size);
   if (size < 1024)
     mu_printf (" %4lu", (unsigned long) size);
@@ -56,7 +52,7 @@ show_struct (msgset_t *msgset, mu_message_t msg, void *data)
   mime_descend (&mclos, show_part, NULL);
 
     /* Mark enclosing message as read */
-  if (mu_mailbox_get_message (mbox, msgset->msg_part[0], &msg) == 0)
+  if (mu_mailbox_get_message (mbox, msgset_msgno (msgset), &msg) == 0)
     util_mark_read (msg);
 
   return 0;
