@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2005-2012, 2014-2017 Free Software Foundation,
-   Inc.
+   Copyright (C) 2003-2020 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -804,9 +803,9 @@ main (int argc, char **argv)
     }
   
   /* Detach from the console if required */
-  if (background && daemon (0, 0) < 0)
+  if (background && (rc = mu_daemon ()) != 0)
     {
-      mu_error (_("cannot switch to background: %s"), mu_strerror (errno));
+      mu_error (_("cannot switch to background: %s"), mu_strerror (rc));
       return 1;
     }
 
