@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2017 Free Software Foundation, Inc.
+   Copyright (C) 2009-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,27 @@
 void
 mu_py_script_init (int argc, char *argv[])
 {
+  wchar_t **wargv;
+  int i;
+  
   if (!Py_IsInitialized ())
     Py_Initialize ();
-  PySys_SetArgv (argc, argv);
+  wargv = PyMem_Calloc (argc, sizeof (wargv[0]));
+  if (!wargv)
+    {
+      PyErr_SetNone (PyExc_MemoryError);
+      return; /* FIXME */
+    }
+  for (i = 0; i < argc; i++)
+    {
+      wargv[i] = Py_DecodeLocale (argv[i], NULL);
+      if (!wargv[i])
+	{
+	  PyErr_SetNone (PyExc_MemoryError);
+	  return; /* FIXME */
+	}
+    }
+  PySys_SetArgv (argc, wargv);
 }
 
 void
@@ -39,8 +57,9 @@ int
 mu_py_script_run (const char *python_filename, mu_py_script_data *data)
 {
   FILE *fp;
-  PyObject *py_module;
-
+  PyObject *py_module, *sysmodules;
+  struct PyModuleDef moddef = { .m_base = PyModuleDef_HEAD_INIT };
+  
   if (!python_filename)
     return MU_ERR_OUT_PTR_NULL;
 
@@ -48,13 +67,21 @@ mu_py_script_run (const char *python_filename, mu_py_script_data *data)
   if (!fp)
     return errno;
 
-  py_module = Py_InitModule (data->module_name, nomethods);
+  moddef.m_name = data->module_name;
+  moddef.m_doc = "";
+  moddef.m_size = -1;
+  moddef.m_methods = nomethods;
+  
+  py_module = PyModule_Create (&moddef);
   if (!py_module)
     return MU_ERR_FAILURE;
 
   for (; data->attrs->name; data->attrs++)
     PyObject_SetAttrString (py_module, data->attrs->name, data->attrs->obj);
 
+  sysmodules = PyImport_GetModuleDict ();
+  PyMapping_SetItemString (sysmodules, moddef.m_name, py_module);
+  
   if (PyRun_SimpleFile (fp, python_filename))
     return MU_ERR_FAILURE;
 
