@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
+   Copyright (C) 2009-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -25,49 +25,18 @@ _repr (PyObject *self)
 {
   char buf[80];
   sprintf (buf, "<" PY_MODULE "." PY_CSNAME " instance at %p>", self);
-  return PyString_FromString (buf);
+  return PyUnicode_FromString (buf);
 }
 
 static PyTypeObject PySieveMachineType = {
-  PyObject_HEAD_INIT(NULL)
-  0,                         /* ob_size */
-  PY_MODULE "." PY_CSNAME,   /* tp_name */
-  sizeof (PySieveMachine),   /* tp_basicsize */
-  0,                         /* tp_itemsize */
-  (destructor)_py_dealloc,   /* tp_dealloc */
-  0,                         /* tp_print */
-  0,                         /* tp_getattr; __getattr__ */
-  0,                         /* tp_setattr; __setattr__ */
-  0,                         /* tp_compare; __cmp__ */
-  _repr,                     /* tp_repr; __repr__ */
-  0,                         /* tp_as_number */
-  0,                         /* tp_as_sequence */
-  0,                         /* tp_as_mapping */
-  0,                         /* tp_hash; __hash__ */
-  0,                         /* tp_call; __call__ */
-  _repr,                     /* tp_str; __str__ */
-  0,                         /* tp_getattro */
-  0,                         /* tp_setattro */
-  0,                         /* tp_as_buffer */
-  Py_TPFLAGS_DEFAULT,        /* tp_flags */
-  "",                        /* tp_doc */
-  0,                         /* tp_traverse */
-  0,                         /* tp_clear */
-  0,                         /* tp_richcompare */
-  0,                         /* tp_weaklistoffset */
-  0,                         /* tp_iter */
-  0,                         /* tp_iternext */
-  0,                         /* tp_methods */
-  0,                         /* tp_members */
-  0,                         /* tp_getset */
-  0,                         /* tp_base */
-  0,                         /* tp_dict */
-  0,                         /* tp_descr_get */
-  0,                         /* tp_descr_set */
-  0,                         /* tp_dictoffset */
-  0,                         /* tp_init */
-  0,                         /* tp_alloc */
-  0,                         /* tp_new */
+  .ob_base = { PyObject_HEAD_INIT(NULL) },
+  .tp_name = PY_MODULE "." PY_CSNAME,
+  .tp_basicsize = sizeof (PySieveMachine),
+  .tp_dealloc = (destructor)_py_dealloc,
+  .tp_repr = _repr,
+  .tp_str = _repr,
+  .tp_flags = Py_TPFLAGS_DEFAULT,
+  .tp_doc = "",
 };
 
 PySieveMachine *
@@ -101,15 +70,17 @@ api_sieve_machine_init (PyObject *self, PyObject *args)
 
   status = mu_memory_stream_create (&str, MU_STREAM_RDWR);
   if (status)
-    return _ro (PyInt_FromLong (status));
+    return _ro (PyLong_FromLong (status));
   status = mu_log_stream_create (&estr, str);
   mu_stream_unref (str);
   if (status)
-    return _ro (PyInt_FromLong (status));
+    return _ro (PyLong_FromLong (status));
   
-  status = mu_sieve_machine_init_ex (&py_mach->mach, NULL, estr);
+  status = mu_sieve_machine_create (&py_mach->mach);
+  if (status == 0)
+    mu_sieve_set_diag_stream (py_mach->mach, estr);
   mu_stream_unref (estr);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -142,7 +113,7 @@ api_sieve_machine_error_text (PyObject *self, PyObject *args)
   
   if (status)
     PyErr_SetString (PyExc_RuntimeError, mu_strerror (status));
-  retval = PyString_FromStringAndSize ((char*) trans[0], length);
+  retval = PyUnicode_FromStringAndSize ((char*) trans[0], length);
 
   mu_stream_unref (estr);
   return _ro (retval);
@@ -177,7 +148,7 @@ api_sieve_compile (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_sieve_compile (py_mach->mach, name);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -190,7 +161,7 @@ api_sieve_disass (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_sieve_disass (py_mach->mach);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -210,7 +181,7 @@ api_sieve_mailbox (PyObject *self, PyObject *args)
     }
 
   status = mu_sieve_mailbox (py_mach->mach, py_mbox->mbox);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -230,12 +201,11 @@ api_sieve_message (PyObject *self, PyObject *args)
     }
 
   status = mu_sieve_message (py_mach->mach, py_msg->msg);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static void
-_sieve_action_printer (void *data, mu_stream_t stream,
-		       size_t msgno, mu_message_t msg,
+_sieve_action_printer (mu_sieve_machine_t mach,
 		       const char *action, const char *fmt, va_list ap)
 {
   PyObject *py_args;
@@ -256,31 +226,33 @@ _sieve_action_printer (void *data, mu_stream_t stream,
 	  PyStream *py_stm = PyStream_NEW ();
 	  if (py_stm)
 	    {
-	      py_stm->stm = stream;
-	      mu_stream_ref (stream);
-	  
-	      py_msg->msg = msg;
+	      size_t msgno;
+	      
+	      mu_sieve_get_diag_stream (mach, &py_stm->stm);
+	      msgno = mu_sieve_get_message_num (mach);
+	      
+	      py_msg->msg = mu_sieve_get_message (mach);
 	      Py_INCREF (py_msg);
 
 	      PyDict_SetItemString (py_dict, "msgno",
-				    PyInt_FromSize_t (msgno));
+				    PyLong_FromSize_t (msgno));
 	      PyDict_SetItemString (py_dict, "msg", (PyObject *)py_msg);
 	      PyDict_SetItemString (py_dict, "action",
-				    PyString_FromString (action ? action : ""));
+				    PyUnicode_FromString (mu_prstr (action)));
 
 	      if (mu_vasnprintf (&buf, &buflen, fmt, ap))
 		{
-		  mu_stream_unref (stream);
+		  mu_stream_destroy (&py_stm->stm);
 		  return;
 		}
 	      PyDict_SetItemString (py_dict, "text",
-				    PyString_FromString (buf ? buf : ""));
+				    PyUnicode_FromString (mu_prstr (buf)));
 	      free (buf);
 
 	      py_args = PyTuple_New (1);
 	      if (py_args)
 		{
-		  struct _mu_py_sieve_logger *s = data;
+		  struct _mu_py_sieve_logger *s = mu_sieve_get_data (mach);
 		  PyObject *py_fnc = s->py_action_printer;
 
 		  Py_INCREF (py_dict);
@@ -350,6 +322,14 @@ static PyMethodDef methods[] = {
   { NULL, NULL, 0, NULL }
 };
 
+static struct PyModuleDef moduledef = {
+  PyModuleDef_HEAD_INIT,
+  PY_MODULE,
+  NULL,
+  -1,
+  methods
+};
+
 int
 mu_py_init_sieve (void)
 {
@@ -361,7 +341,7 @@ void
 _mu_py_attach_sieve (void)
 {
   PyObject *m;
-  if ((m = _mu_py_attach_module (PY_MODULE, methods)))
+  if ((m = _mu_py_attach_module (&moduledef)))
     {
       Py_INCREF (&PySieveMachineType);
       PyModule_AddObject (m, PY_CSNAME, (PyObject *)&PySieveMachineType);
